==> cdktf_cdktf_provider_azurerm-0.5.13-py3-none-any.whl: package/lib/data-azurerm-image.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzurermImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#name DataAzurermImage#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#name_regex DataAzurermImage#name_regex}.
     *
     * @stability stable
     */
    readonly nameRegex?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#resource_group_name DataAzurermImage#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#sort_descending DataAzurermImage#sort_descending}.
     *
     * @stability stable
     */
    readonly sortDescending?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#timeouts DataAzurermImage#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzurermImageTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzurermImageDataDisk extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get blobUri(): string;
    /**
     * @stability stable
     */
    get caching(): string;
    /**
     * @stability stable
     */
    get lun(): number;
    /**
     * @stability stable
     */
    get managedDiskId(): string;
    /**
     * @stability stable
     */
    get sizeGb(): number;
}
/**
 * @stability stable
 */
export declare class DataAzurermImageOsDisk extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get blobUri(): string;
    /**
     * @stability stable
     */
    get caching(): string;
    /**
     * @stability stable
     */
    get managedDiskId(): string;
    /**
     * @stability stable
     */
    get osState(): string;
    /**
     * @stability stable
     */
    get osType(): string;
    /**
     * @stability stable
     */
    get sizeGb(): number;
}
/**
 * @stability stable
 */
export interface DataAzurermImageTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#read DataAzurermImage#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
export declare function dataAzurermImageTimeoutsToTerraform(struct?: DataAzurermImageTimeoutsOutputReference | DataAzurermImageTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DataAzurermImageTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataAzurermImageTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataAzurermImageTimeouts | undefined);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/image azurerm_image}.
 *
 * @stability stable
 */
export declare class DataAzurermImage extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/image azurerm_image} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAzurermImageConfig);
    /**
     * @stability stable
     */
    dataDisk(index: string): DataAzurermImageDataDisk;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get location(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _nameRegex?;
    /**
     * @stability stable
     */
    get nameRegex(): string;
    /**
     * @stability stable
     */
    set nameRegex(value: string);
    /**
     * @stability stable
     */
    resetNameRegex(): void;
    /**
     * @stability stable
     */
    get nameRegexInput(): string | undefined;
    /**
     * @stability stable
     */
    osDisk(index: string): DataAzurermImageOsDisk;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    private _sortDescending?;
    /**
     * @stability stable
     */
    get sortDescending(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sortDescending(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSortDescending(): void;
    /**
     * @stability stable
     */
    get sortDescendingInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    tags(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get zoneResilient(): cdktf.IResolvable;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DataAzurermImageTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DataAzurermImageTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzurermImageTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.5.58-py3-none-any.whl: package/lib/data-azurerm-image.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermImageConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#name DataAzurermImage#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#name_regex DataAzurermImage#name_regex}
    */
    readonly nameRegex?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#resource_group_name DataAzurermImage#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#sort_descending DataAzurermImage#sort_descending}
    */
    readonly sortDescending?: boolean | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#timeouts DataAzurermImage#timeouts}
    */
    readonly timeouts?: DataAzurermImageTimeouts;
}
export declare class DataAzurermImageDataDisk extends cdktf.ComplexComputedList {
    get blobUri(): string;
    get caching(): string;
    get lun(): number;
    get managedDiskId(): string;
    get sizeGb(): number;
}
export declare class DataAzurermImageOsDisk extends cdktf.ComplexComputedList {
    get blobUri(): string;
    get caching(): string;
    get managedDiskId(): string;
    get osState(): string;
    get osType(): string;
    get sizeGb(): number;
}
export interface DataAzurermImageTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/image#read DataAzurermImage#read}
    */
    readonly read?: string;
}
export declare function dataAzurermImageTimeoutsToTerraform(struct?: DataAzurermImageTimeoutsOutputReference | DataAzurermImageTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermImageTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermImageTimeouts | undefined;
    set internalValue(value: DataAzurermImageTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/image azurerm_image}
*/
export declare class DataAzurermImage extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/image azurerm_image} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermImageConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermImageConfig);
    dataDisk(index: string): DataAzurermImageDataDisk;
    get id(): string;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _nameRegex?;
    get nameRegex(): string;
    set nameRegex(value: string);
    resetNameRegex(): void;
    get nameRegexInput(): string | undefined;
    osDisk(index: string): DataAzurermImageOsDisk;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _sortDescending?;
    get sortDescending(): boolean | cdktf.IResolvable;
    set sortDescending(value: boolean | cdktf.IResolvable);
    resetSortDescending(): void;
    get sortDescendingInput(): boolean | cdktf.IResolvable | undefined;
    tags(key: string): string | cdktf.IResolvable;
    get zoneResilient(): cdktf.IResolvable;
    private _timeouts;
    get timeouts(): DataAzurermImageTimeoutsOutputReference;
    putTimeouts(value: DataAzurermImageTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermImageTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
